@@ -41,19 +41,18 @@
 #' @param varimp variable importance function whose arguments are the
 #'   \code{object} returned by \code{fit}, optional arguments passed from calls
 #'   to \code{\link{varimp}}, and an ellipsis.
-#' @param ... arguments passed from other methods.
+#' @param ... arguments passed to other methods.
 #'
 #' @details
 #' If supplied, the \code{grid} function should return a list whose elements are
 #' named after and contain values of parameters to include in a tuning grid to
 #' be constructed automatically by the package.
 #'
-#' Argument \code{data} in the \code{fit} function may be converted to a data
-#' frame with the \code{as.data.frame} function as needed.  The function should
-#' return the object resulting from the model fit.
-#'
-#' Values returned by the \code{predict} functions should be formatted according
-#' to the response variable types below.
+#' Arguments \code{data} and \code{newdata} in the \code{fit} and \code{predict}
+#' functions may be converted to data frames with \code{as.data.frame()}
+#' if needed for their operation.  The \code{fit} function should return the
+#' object resulting from the model fit.  Values returned by the \code{predict}
+#' functions should be formatted according to the response variable types below.
 #' \describe{
 #'   \item{factor}{vector or column matrix of probabilities for the second level
 #'     of binary factors or a matrix whose columns contain the probabilities for
@@ -80,10 +79,11 @@
 #'   response_types = "binary",
 #'   weights = TRUE,
 #'   fit = function(formula, data, weights, ...) {
-#'     glm(formula, data = data, weights = weights, family = binomial, ...)
+#'     glm(formula, data = as.data.frame(data), weights = weights,
+#'         family = binomial, ...)
 #'   },
 #'   predict = function(object, newdata, ...) {
-#'     predict(object, newdata = newdata, type = "response")
+#'     predict(object, newdata = as.data.frame(newdata), type = "response")
 #'   },
 #'   varimp = function(object, ...) {
 #'     pchisq(coef(object)^2 / diag(vcov(object)), 1)
@@ -101,8 +101,8 @@ MLModel <- function(
   gridinfo = tibble::tibble(
     param = character(), get_values = list(), default = logical()
   ),
-  fit = function(formula, data, weights, ...) stop("no fit function"),
-  predict = function(object, newdata, times, ...) stop("no predict function"),
+  fit = function(formula, data, weights, ...) stop("No fit function."),
+  predict = function(object, newdata, times, ...) stop("No predict function."),
   varimp = function(object, ...) NULL, ...
 ) {
 
@@ -110,42 +110,48 @@ MLModel <- function(
   stopifnot(response_types %in% settings("response_types"))
   stopifnot(length(weights) %in% c(1, length(response_types)))
 
+  stopifnot(is_tibble(gridinfo))
+  gridinfo <- new_gridinfo(
+    param = gridinfo[["param"]],
+    get_values = gridinfo[["get_values"]],
+    default = gridinfo[["default"]]
+  )
+
   new("MLModel",
-      name = name,
-      label = label,
-      packages = packages,
-      response_types = response_types,
-      weights = weights,
-      predictor_encoding = match.arg(predictor_encoding),
-      params = params,
-      gridinfo = gridinfo,
-      fit = fit,
-      predict = predict,
-      varimp = varimp)
+    name = name,
+    label = label,
+    packages = packages,
+    response_types = response_types,
+    weights = weights,
+    predictor_encoding = match.arg(predictor_encoding),
+    params = params,
+    gridinfo = gridinfo,
+    fit = fit,
+    predict = predict,
+    varimp = varimp,
+    ...
+  )
 }
 
 
-setMethod("initialize", "MLModel",
-  function(.Object, ..., gridinfo = new_gridinfo()) {
-    stopifnot(is_tibble(gridinfo))
-    .Object@gridinfo <- new_gridinfo(
-      param = gridinfo[["param"]],
-      get_values = gridinfo[["get_values"]],
-      default = gridinfo[["default"]]
-    )
-    .Object <- callNextMethod(.Object, ...)
-    .Object
-  }
-)
+update.MLModel <- function(
+  object, params = list(), quote = TRUE, new_id = FALSE, ...
+) {
+  new_params <- as(object, "list")
+  new_params[names(params)] <- params
+  res <- do.call(object@name, new_params, quote = quote)
+  if (!new_id) res@id <- object@id
+  res
+}
 
 
-MLModelFit <- function(object, Class, model, x) {
-  model@x <- prep(x)
+MLModelFit <- function(object, Class, model, input) {
+  model@input <- prep(input)
 
   if (is(object, Class)) {
     object <- unMLModelFit(object)
   } else if (is(object, "MLModelFit")) {
-    throw(Error("cannot change MLModelFit class"))
+    throw(Error("Cannot change MLModelFit class."))
   }
 
   if (!is(model, "MLModel")) throw(TypeError(model, "MLModel", "'model'"))
