@@ -22,8 +22,8 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{factor}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'   \item{Response types:}{\code{factor}}
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameters:}{
 #'     \code{mfinal}, \code{maxdepth}, \code{coeflearn}*
 #'   }
 #' }
@@ -52,18 +52,15 @@ AdaBoostModel <- function(
 
   coeflearn <- match.arg(coeflearn)
 
-  args <- new_params(environment())
-  is_main <- names(args) %in% c("boos", "mfinal", "coeflearn")
-  params <- args[is_main]
-  params$control <- as.call(c(.(list), args[!is_main]))
-
   MLModel(
+
     name = "AdaBoostModel",
     label = "Boosting with Classification Trees",
     packages = "adabag",
     response_types = "factor",
     predictor_encoding = "model.frame",
-    params = params,
+    params = new_params(environment()),
+
     gridinfo = new_gridinfo(
       param = c("mfinal", "maxdepth", "coeflearn"),
       get_values = c(
@@ -73,16 +70,23 @@ AdaBoostModel <- function(
       ),
       default = c(TRUE, TRUE, FALSE)
     ),
-    fit = function(formula, data, weights, ...) {
-      adabag::boosting(formula, data = as.data.frame(data), ...)
+
+    fit = function(formula, data, weights, boos, mfinal, coeflearn, ...) {
+      adabag::boosting(
+        formula, data = as.data.frame(data), boos = boos, mfinal = mfinal,
+        coeflearn = coeflearn, control = list(...)
+      )
     },
+
     predict = function(object, newdata, ...) {
       newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata)$prob
     },
+
     varimp = function(object, ...) {
       object$importance
     }
+
   )
 
 }
