@@ -11,11 +11,11 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{Surv}}
+#'   \item{Response types:}{\code{Surv}}
 #' }
 #'
-#' Default values for the \code{NULL} arguments and further model details can be
-#' found in the source link below.
+#' Default values and further model details can be found in the source links
+#' below.
 #'
 #' In calls to \code{\link{varimp}} for \code{CoxModel} and
 #' \code{CoxStepAICModel}, numeric argument \code{base} may be specified for the
@@ -39,23 +39,21 @@ CoxModel <- function(ties = c("efron", "breslow", "exact"), ...) {
 
   ties <- match.arg(ties)
 
-  args <- new_params(environment(), ...)
-  is_main <- names(args) %in% c("ties", "eps", "iter.max")
-  params <- args[is_main]
-  params$tol <- args$toler.chol
-
   MLModel(
+
     name = "CoxModel",
     label = "Cox Regression",
     packages = "survival",
     response_types = "Surv",
     weights = TRUE,
     predictor_encoding = "model.matrix",
-    params = params,
+    params = new_params(environment(), ...),
+
     fit = function(formula, data, weights, ...) {
-      survival::coxph(formula, data = as.data.frame(data), weights = weights,
-                      ...)
+      data <- as.data.frame(data)
+      survival::coxph(formula, data = data, weights = weights, ...)
     },
+
     predict = function(object, newdata, model, ...) {
       y <- object$y
       newdata <- as.data.frame(newdata)
@@ -63,9 +61,11 @@ CoxModel <- function(ties = c("efron", "breslow", "exact"), ...) {
       new_lp <- predict(object, newdata = newdata, type = "lp")
       predict(y, lp, new_lp, weights = case_weights(model), ...)
     },
+
     varimp = function(object, base = exp(1), ...) {
       varimp_pval(object, base = base)
     }
+
   )
 
 }
@@ -90,19 +90,18 @@ MLModelFunction(CoxModel) <- NULL
 #'
 CoxStepAICModel <- function(
   ties = c("efron", "breslow", "exact"), ...,
-  direction = c("both", "backward", "forward"), scope = NULL, k = 2,
+  direction = c("both", "backward", "forward"), scope = list(), k = 2,
   trace = FALSE, steps = 1000
 ) {
 
   direction <- match.arg(direction)
 
-  args <- new_params(environment())
-  is_step <- names(args) %in% c("direction", "scope", "k", "trace", "steps")
-  params <- args[is_step]
-
+  params <- new_params(environment())
   stepmodel <- CoxModel(ties = ties, ...)
+  params <- params[setdiff(names(params), names(stepmodel@params))]
 
   MLModel(
+
     name = "CoxStepAICModel",
     label = "Cox Regression (Stepwise)",
     packages = c(stepmodel@packages, "MASS"),
@@ -110,8 +109,10 @@ CoxStepAICModel <- function(
     weights = stepmodel@weights,
     predictor_encoding = stepmodel@predictor_encoding,
     params = c(stepmodel@params, params),
-    fit = function(formula, data, weights, direction = "both", scope = list(),
-                   k = 2, trace = 1, steps = 1000, ...) {
+
+    fit = function(
+      formula, data, weights, direction, scope = list(), k, trace, steps, ...
+    ) {
       environment(formula) <- environment()
       stepargs <- stepAIC_args(formula, direction, scope)
       data <- as.data.frame(data)
@@ -121,8 +122,11 @@ CoxStepAICModel <- function(
         steps = steps
       )
     },
+
     predict = stepmodel@predict,
+
     varimp = stepmodel@varimp
+
   )
 
 }
