@@ -21,16 +21,16 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{binary factor}, \code{BinomialVariate},
+#'   \item{Response types:}{\code{binary factor}, \code{BinomialVariate},
 #'     \code{NegBinomialVariate}, \code{numeric}, \code{PoissonVariate},
 #'     \code{Surv}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameter:}{
 #'     \code{mstop}
 #'   }
 #' }
 #'
-#' Default values for the \code{NULL} arguments and further model details can be
-#' found in the source links below.
+#' Default values and further model details can be found in the source links
+#' below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -56,12 +56,8 @@ GAMBoostModel <- function(
   baselearner <- match.arg(baselearner)
   risk <- match.arg(risk)
 
-  args <- new_params(environment())
-  is_main <- names(args) %in% c("family", "baselearner", "dfbase")
-  params <- args[is_main]
-  params$control <- as.call(c(.(mboost::boost_control), args[!is_main]))
-
   MLModel(
+
     name = "GAMBoostModel",
     label = "Gradient Boosting with Additive Models",
     packages = "mboost",
@@ -69,14 +65,18 @@ GAMBoostModel <- function(
                        "numeric", "PoissonVariate", "Surv"),
     weights = TRUE,
     predictor_encoding = "model.frame",
-    params = params,
+    params = new_params(environment()),
+
     gridinfo = new_gridinfo(
       param = "mstop",
       get_values = c(
         function(n, ...) round(seq_range(0, 50, c(1, 1000), n + 1))
       )
     ),
-    fit = function(formula, data, weights, family = NULL, ...) {
+
+    fit = function(
+      formula, data, weights, family = NULL, baselearner, dfbase, ...
+    ) {
       attach_objects(list(
         bbs = mboost::bbs,
         bols = mboost::bols,
@@ -95,9 +95,13 @@ GAMBoostModel <- function(
           "Surv" = mboost::CoxPH()
         )
       }
-      mboost::gamboost(formula, data = as.data.frame(data), na.action = na.pass,
-                       weights = weights, family = family, ...)
+      mboost::gamboost(
+        formula, data = as.data.frame(data), na.action = na.pass,
+        weights = weights, family = family, baselearner = baselearner,
+        dfbase = dfbase, control = mboost::boost_control(...)
+      )
     },
+
     predict = function(object, newdata, model, ...) {
       newdata <- as.data.frame(newdata)
       if (object$family@name == "Cox Partial Likelihood") {
@@ -108,9 +112,11 @@ GAMBoostModel <- function(
         predict(object, newdata = newdata, type = "response")
       }
     },
+
     varimp = function(object, ...) {
       structure(mboost::varimp(object), class = "numeric")
     }
+
   )
 
 }
