@@ -8,8 +8,8 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{factor}, \code{numeric}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'   \item{Response types:}{\code{factor}, \code{numeric}}
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameters:}{
 #'     \code{ncomp}
 #'   }
 #' }
@@ -30,20 +30,23 @@
 PLSModel <- function(ncomp = 1, scale = FALSE) {
 
   MLModel(
+
     name = "PLSModel",
     label = "Partial Least Squares",
     packages = "pls",
     response_types = c("factor", "numeric"),
     predictor_encoding = "model.matrix",
     params = new_params(environment()),
+
     gridinfo = new_gridinfo(
       param = "ncomp",
       get_values = c(
         function(n, data, ...) {
-          seq_len(min(nrow(data), nvars(data, PLSModel) - 1, n))
+          seq_len(min(n, nrow(data), nvars(data, PLSModel) - 1))
         }
       )
     ),
+
     fit = function(formula, data, weights, ...) {
       y <- response(data)
       data <- as.data.frame(data)
@@ -51,26 +54,28 @@ PLSModel <- function(ncomp = 1, scale = FALSE) {
         mm <- model.matrix(~ y - 1)
         colnames(mm) <- levels(y)
         data[[response(formula)]] <- mm
-
       }
       pls::plsr(formula, data = data, ...)
     },
+
     predict = function(object, newdata, ...) {
       newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata, ncomp = object$ncomp,
               type = "response")
     },
+
     varimp = function(object, ...) {
       beta <- coef(object, comps = seq_len(object$ncomp))
       perf <- quote(MSEP.mvr(x)$val[1, , , drop = FALSE]) %>%
         eval(list(x = object), asNamespace("pls"))
-      vi <- map_num(function(i) {
+      vi <- map("num", function(i) {
         drop(as.matrix(abs(beta[, i, ])) %*% prop.table(-diff(perf[, i, ])))
       }, seq_len(ncol(beta)))
       dimnames(vi) <- dimnames(beta)[1:2]
       if (ncol(vi) <= 2) vi <- vi[, 1]
       vi
     }
+
   )
 
 }
