@@ -8,7 +8,7 @@
 #' @param ntree number of trees.
 #' @param mtry number of variables randomly selected as candidates for splitting
 #'   a node.
-#' @param nodesize forest average number of unique cases in a terminal node.
+#' @param nodesize minumum size of terminal nodes.
 #' @param nodedepth maximum depth to which a tree should be grown.
 #' @param splitrule splitting rule (see \code{\link[randomForestSRC]{rfsrc}}).
 #' @param nsplit non-negative integer value for number of random splits to
@@ -42,15 +42,15 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{factor}, \code{matrix}, \code{numeric},
+#'   \item{Response types:}{\code{factor}, \code{matrix}, \code{numeric},
 #'     \code{Surv}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameters:}{
 #'     \code{mtry}, \code{nodesize}
 #'   }
 #' }
 #'
-#' Default values for the \code{NULL} arguments and further model details can be
-#' found in the source link below.
+#' Default values and further model details can be found in the source links
+#' below.
 #'
 #' In calls to \code{\link{varimp}} for \code{RFSRCModel}, argument
 #' \code{type} may be specified as \code{"permute"} (default) for permutation of
@@ -71,19 +71,19 @@
 #' ## Requires prior installation of suggested package randomForestSRC to run
 #'
 #' model_fit <- fit(sale_amount ~ ., data = ICHomes, model = RFSRCModel)
-#' varimp(model_fit, type = "random", scale = TRUE)
+#' varimp(model_fit, method = "model", type = "random", scale = TRUE)
 #' }
 #'
 RFSRCModel <- function(
-  ntree = 1000, mtry = NULL, nodesize = NULL, nodedepth = NULL,
-  splitrule = NULL, nsplit = 10, block.size = NULL,
+  ntree = 1000, mtry = integer(), nodesize = integer(), nodedepth = integer(),
+  splitrule = character(), nsplit = 10, block.size = integer(),
   samptype = c("swor", "swr"), membership = FALSE,
   sampsize = if (samptype == "swor") function(x) 0.632 * x else function(x) x,
-  nimpute = 1, ntime = NULL,
+  nimpute = 1, ntime = integer(),
   proximity = c(FALSE, TRUE, "inbag", "oob", "all"),
   distance = c(FALSE, TRUE, "inbag", "oob", "all"),
   forest.wt = c(FALSE, TRUE, "inbag", "oob", "all"),
-  xvar.wt = NULL, split.wt = NULL,
+  xvar.wt = numeric(), split.wt = numeric(),
   var.used = c(FALSE, "all.trees", "by.tree"),
   split.depth = c(FALSE, "all.trees", "by.tree"),
   do.trace = FALSE, statistics = FALSE
@@ -98,6 +98,7 @@ RFSRCModel <- function(
   split.depth <- match.arg(as.character(split.depth), split.depth)
 
   MLModel(
+
     name = "RFSRCModel",
     label = "Random Forest (SRC)",
     packages = "randomForestSRC",
@@ -105,6 +106,7 @@ RFSRCModel <- function(
     weights = TRUE,
     predictor_encoding = "model.frame",
     params = new_params(environment()),
+
     gridinfo = new_gridinfo(
       param = c("mtry", "nodesize"),
       get_values = c(
@@ -112,18 +114,19 @@ RFSRCModel <- function(
         function(n, data, ...) round(seq(1, min(20, nrow(data)), length = n))
       )
     ),
+
     fit = function(formula, data, weights, ...) {
       y <- response(data)
       data <- as.data.frame(data)
       family <- switch_class(y,
         "matrix" = {
-          colnames(y) <- paste0("y", seq_len(ncol(y)))
+          colnames(y) <- make_names_len(ncol(y), "y")
           "Multivar"
         },
         "Surv" = "Surv"
       )
       if (!is.null(family)) {
-        y_names <- map_chr(recipes::rand_id, colnames(y))
+        y_names <- map("char", recipes::rand_id, colnames(y))
         data[[response(formula)]] <- NULL
         data[y_names] <- y
         formula[[2]] <- as.call(map(as.name, c(family, y_names)))
@@ -131,29 +134,32 @@ RFSRCModel <- function(
       randomForestSRC::rfsrc(formula, data = data, na.action = "na.impute",
                              case.wt = weights, ...)
     },
+
     predict = function(object, newdata, model, ...) {
       newdata <- as.data.frame(newdata)
       pred <- randomForestSRC::predict.rfsrc(object, newdata = newdata)
       if (pred$family == "regr+") {
         y_names <- pred$yvar.names
         names(y_names) <- sub("_.*", "", y_names)
-        map_simplify(function(name) pred$regrOutput[[name]]$predicted, y_names)
+        simplify(map(function(name) pred$regrOutput[[name]]$predicted, y_names))
       } else if (pred$family == "surv") {
         predict(Surv(pred$time.interest), pred$survival, ...)
       } else {
         pred$predicted
       }
     },
+
     varimp = function(object, type = c("permute", "random", "anti"), ...) {
       vi <- randomForestSRC::vimp(object, importance = match.arg(type))
       if (vi$family == "regr+") {
         y_names <- vi$yvar.names
         names(y_names) <- sub("_.*", "", y_names)
-        map_simplify(function(name) vi$regrOutput[[name]]$importance, y_names)
+        simplify(map(function(name) vi$regrOutput[[name]]$importance, y_names))
       } else {
         vi$importance
       }
     }
+
   )
 
 }
@@ -164,14 +170,12 @@ MLModelFunction(RFSRCModel) <- NULL
 #' @rdname RFSRCModel
 #'
 RFSRCFastModel <- function(
-  ntree = 500, sampsize = function(x) min(0.632 * x, max(150, x^0.75)),
+  ntree = 500, sampsize = function(x) min(0.632 * x, max(x^0.75, 150)),
   ntime = 50, terminal.qualts = FALSE, ...
 ) {
-
   model <- RFSRCModel(ntree = ntree, sampsize = sampsize, ntime = ntime, ...)
   model@params$terminal.qualts <- terminal.qualts
   model
-
 }
 
 MLModelFunction(RFSRCFastModel) <- NULL
