@@ -12,15 +12,15 @@
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{factor}, \code{numeric}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters:}{
+#'   \item{Response types:}{\code{factor}, \code{numeric}}
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameters:}{
 #'     \code{mtry}, \code{nodesize}*
 #'   }
 #' }
 #' * excluded from grids by default
 #'
-#' Default values for the \code{NULL} arguments and further model details can be
-#' found in the source link below.
+#' Default values and further model details can be found in the source link
+#' below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -37,16 +37,18 @@
 RandomForestModel <- function(
   ntree = 500,
   mtry = .(if (is.factor(y)) floor(sqrt(nvars)) else max(floor(nvars / 3), 1)),
-  replace = TRUE, nodesize = .(if (is.factor(y)) 1 else 5), maxnodes = NULL
+  replace = TRUE, nodesize = .(if (is.factor(y)) 1 else 5), maxnodes = integer()
 ) {
 
   MLModel(
+
     name = "RandomForestModel",
     label = "Random Forests",
     packages = "randomForest",
     response_types = c("factor", "numeric"),
     predictor_encoding = "model.frame",
     params = new_params(environment()),
+
     gridinfo = new_gridinfo(
       param = c("mtry", "nodesize"),
       get_values = c(
@@ -55,21 +57,25 @@ RandomForestModel <- function(
       ),
       default = c(TRUE, FALSE)
     ),
+
     fit = function(formula, data, weights, ...) {
-      eval_fit(data,
-               formula = randomForest::randomForest(formula,
-                                                    data = as.data.frame(data),
-                                                    ...),
-               matrix = randomForest::randomForest(x, y, ...))
+      eval_fit(
+        data,
+        formula = randomForest::randomForest(formula, data = data, ...),
+        matrix = randomForest::randomForest(x, y, ...)
+      )
     },
+
     predict = function(object, newdata, model, ...) {
       newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata,
               type = if (is.factor(response(model))) "prob" else "response")
     },
+
     varimp = function(object, ...) {
       randomForest::importance(object)
     }
+
   )
 
 }
