@@ -26,12 +26,12 @@
 #'   kernels as a convenient way of normalizing patterns without the need to
 #'   modify the data itself.
 #' @param offset offset used in polynomial and hyperbolic tangent kernels.
-#' @param ... arguments passed to \code{SVMModel}.
+#' @param ... arguments passed to \code{SVMModel} from the other constructors.
 #'
 #' @details
 #' \describe{
-#'   \item{Response Types:}{\code{factor}, \code{numeric}}
-#'   \item{\link[=TunedModel]{Automatic Tuning} of Grid Parameters}{
+#'   \item{Response types:}{\code{factor}, \code{numeric}}
+#'   \item{\link[=TunedModel]{Automatic tuning} of grid parameters:}{
 #'     \itemize{
 #'       \item SVMANOVAModel: \code{C}, \code{degree}
 #'       \item SVMBesselModel: \code{C}, \code{order}, \code{degree}
@@ -45,8 +45,8 @@
 #'
 #' Arguments \code{kernel} and \code{kpar} are automatically set by the
 #' kernel-specific constructor functions.
-#' Default values for the \code{NULL} arguments and further model details can be
-#' found in the source link below.
+#' Default values and further model details can be found in the source link
+#' below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -57,7 +57,7 @@
 #' fit(sale_amount ~ ., data = ICHomes, model = SVMRadialModel)
 #'
 SVMModel <- function(
-  scaled = TRUE, type = NULL,
+  scaled = TRUE, type = character(),
   kernel = c("rbfdot", "polydot", "vanilladot", "tanhdot", "laplacedot",
              "besseldot", "anovadot", "splinedot"),
   kpar = "automatic", C = 1, nu = 0.2, epsilon = 0.1, cache = 40, tol = 0.001,
@@ -67,18 +67,22 @@ SVMModel <- function(
   kernel <- match.arg(kernel)
 
   MLModel(
+
     name = "SVMModel",
     label = "Support Vector Machines",
     packages = "kernlab",
     response_types = c("factor", "numeric"),
     predictor_encoding = "model.matrix",
     params = new_params(environment()),
+
     fit = function(formula, data, weights, ...) {
-      eval_fit(data,
-               formula = kernlab::ksvm(formula, data = as.data.frame(data),
-                                       prob.model = TRUE, ...),
-               matrix = kernlab::ksvm(x, y, prob.model = TRUE, ...))
+      eval_fit(
+        data,
+        formula = kernlab::ksvm(formula, data = data, prob.model = TRUE, ...),
+        matrix = kernlab::ksvm(x, y, prob.model = TRUE, ...)
+      )
     },
+
     predict = function(object, newdata, model, ...) {
       newdata <- as.data.frame(newdata)
       kernlab::predict(
@@ -86,6 +90,7 @@ SVMModel <- function(
         type = if (is.factor(response(model))) "probabilities" else "response"
       )
     }
+
   )
 
 }
@@ -96,8 +101,8 @@ MLModelFunction(SVMModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMANOVAModel <- function(sigma = 1, degree = 1, ...) {
-  .SVMModel("SVMANOVAModel", "Support Vector Machines (ANOVA)",
-            "anovadot", environment(), ...)
+  .SVMModel(name = "SVMANOVAModel", label = "Support Vector Machines (ANOVA)",
+            model = "anovadot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMANOVAModel) <- NULL
@@ -106,8 +111,8 @@ MLModelFunction(SVMANOVAModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMBesselModel <- function(sigma = 1, order = 1, degree = 1, ...) {
-  .SVMModel("SVMBesselModel", "Support Vector Machines (Bessel)",
-            "besseldot", environment(), ...)
+  .SVMModel(name = "SVMBesselModel", label = "Support Vector Machines (Bessel)",
+            model = "besseldot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMBesselModel) <- NULL
@@ -115,9 +120,9 @@ MLModelFunction(SVMBesselModel) <- NULL
 
 #' @rdname SVMModel
 #'
-SVMLaplaceModel <- function(sigma = NULL, ...) {
-  .SVMModel("SVMLaplaceModel", "Support Vector Machines (Laplace)",
-            "laplacedot", environment(), ...)
+SVMLaplaceModel <- function(sigma = numeric(), ...) {
+  .SVMModel(name = "SVMLaplaceModel", label = "Support Vector Machines (Laplace)",
+            model = "laplacedot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMLaplaceModel) <- NULL
@@ -126,8 +131,8 @@ MLModelFunction(SVMLaplaceModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMLinearModel <- function(...) {
-  .SVMModel("SVMLinearModel", "Support Vector Machines (Linear)",
-            "vanilladot", environment(), ...)
+  .SVMModel(name = "SVMLinearModel", label = "Support Vector Machines (Linear)",
+            model = "vanilladot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMLinearModel) <- NULL
@@ -136,8 +141,8 @@ MLModelFunction(SVMLinearModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMPolyModel <- function(degree = 1, scale = 1, offset = 1, ...) {
-  .SVMModel("SVMPolyModel", "Support Vector Machines (Poly)",
-            "polydot", environment(), ...)
+  .SVMModel(name = "SVMPolyModel", label = "Support Vector Machines (Poly)",
+            model = "polydot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMPolyModel) <- NULL
@@ -145,9 +150,9 @@ MLModelFunction(SVMPolyModel) <- NULL
 
 #' @rdname SVMModel
 #'
-SVMRadialModel <- function(sigma = NULL, ...) {
-  .SVMModel("SVMRadialModel", "Support Vector Machines (Radial)",
-            "rbfdot", environment(), ...)
+SVMRadialModel <- function(sigma = numeric(), ...) {
+  .SVMModel(name = "SVMRadialModel", label = "Support Vector Machines (Radial)",
+            model = "rbfdot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMRadialModel) <- NULL
@@ -156,8 +161,8 @@ MLModelFunction(SVMRadialModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMSplineModel <- function(...) {
-  .SVMModel("SVMSplineModel", "Support Vector Machines (Spline)",
-            "splinedot", environment(), ...)
+  .SVMModel(name = "SVMSplineModel", label = "Support Vector Machines (Spline)",
+            model = "splinedot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMSplineModel) <- NULL
@@ -166,23 +171,25 @@ MLModelFunction(SVMSplineModel) <- NULL
 #' @rdname SVMModel
 #'
 SVMTanhModel <- function(scale = 1, offset = 1, ...) {
-  .SVMModel("SVMTanhModel", "Support Vector Machines (Tanh)",
-            "tanhdot", environment(), ...)
+  .SVMModel(name = "SVMTanhModel", label = "Support Vector Machines (Tanh)",
+            model = "tanhdot", envir = environment(), ...)
 }
 
 MLModelFunction(SVMTanhModel) <- NULL
 
 
-.SVMModel <- function(name, label, kernel, envir, ...) {
-  args <- list(...)
-  args$kernel <- kernel
+.SVMModel <- function(name, label, model, envir, ...) {
+  params <- list(...)
+  params$kernel <- model
   kpar <- new_params(envir)
-  args$kpar <- if (kernel %in% c("laplacedot", "rbfdot") && length(kpar) == 0) {
+  params$kpar <- if (
+    params$kernel %in% c("laplacedot", "rbfdot") && is_empty(kpar)
+  ) {
     "automatic"
   } else {
     as.call(c(.(list), kpar))
   }
-  model <- do.call(SVMModel, args, quote = TRUE)
+  model <- do.call(SVMModel, params, quote = TRUE)
   model@name <- name
   model@label <- label
 
@@ -203,7 +210,7 @@ MLModelFunction(SVMTanhModel) <- NULL
       }
     )
   )
-  params <- switch(kernel,
+  grid_params <- switch(params$kernel,
     "anovadot" = c("C", "degree"),
     "besseldot" = c("C", "order", "degree"),
     "laplacedot" = c("C", "sigma"),
@@ -211,7 +218,7 @@ MLModelFunction(SVMTanhModel) <- NULL
     "rbfdot" = c("C", "sigma"),
     "vanilladot" = "C"
   )
-  model@gridinfo <- gridinfo[gridinfo$param %in% params, ]
+  model@gridinfo <- gridinfo[gridinfo$param %in% grid_params, ]
 
   model
 }
