@@ -36,30 +36,27 @@ setMethod("[",
 
 #' @rdname extract-methods
 #'
-"[.ModelFrame" <- function(x, i, j, ..., drop = FALSE) {
-  ninds <- nargs() - 1 - !missing(drop)
-  if (ninds > 1) {
-    if (!missing(j) || drop) {
-      y <- as.data.frame(x)[i, j, drop = drop]
-      if (identical(colnames(x), colnames(y))) {
-        ModelFrame(terms(x), y, na.rm = FALSE)
-      } else y
-    } else NextMethod(drop = FALSE)
-  } else x[, i, drop = FALSE]
-}
+setMethod("[", c(x = "ListOf", i = "ANY", j = "missing", drop = "missing"),
+  function(x, i) {
+    ListOf(asS3(x)[i])
+  }
+)
 
 
 #' @rdname extract-methods
 #'
 setMethod("[", c(x = "ModelFrame", i = "ANY", j = "ANY", drop = "ANY"),
   function(x, i, j, ..., drop = FALSE) {
-    y <- as(x, "ModelFrame")[i, j, drop = drop]
-    if (is(y, "ModelFrame")) {
-      switch_class(x,
-        "ModeledInput" = new(class(x), y, model = x@model),
-        "SelectedInput" = new(class(x), y, inputs = x@inputs, params = x@params)
-      )
-    } else y
+    y <- as.data.frame(x)[i, j, drop = drop]
+    if (identical(colnames(x), colnames(y))) {
+      y <- ModelFrame(terms(x), y, na.rm = FALSE)
+      if (is(x, "ModeledInput")) {
+        y <- new(class(x), y, model = x@model)
+      } else if (is(x, "SelectedInput")) {
+        y <- new(class(x), y, inputs = x@inputs, params = x@params)
+      }
+    }
+    y
   }
 )
 
@@ -78,6 +75,15 @@ setMethod("[", c(x = "ModelFrame", i = "ANY", j = "missing", drop = "ANY"),
 )
 
 
+#' @rdname extract-methods
+#'
+setMethod("[", c(x = "ModelFrame", i = "missing", j = "ANY", drop = "ANY"),
+  function(x, i, j, ..., drop = FALSE) {
+    x[TRUE, j, drop = drop]
+  }
+)
+
+
 #' @rdname extract-methods
 #'
 setMethod("[", c(x = "ModelFrame", i = "missing", j = "missing", drop = "ANY"),
@@ -98,11 +104,11 @@ setMethod("[", c(x = "RecipeGrid", i = "ANY", j = "ANY", drop = "ANY"),
 
 #' @rdname extract-methods
 #'
-setMethod("[", c(x = "Resamples", i = "ANY", j = "ANY", drop = "ANY"),
+setMethod("[", c(x = "Resample", i = "ANY", j = "ANY", drop = "ANY"),
   function(x, i, j, ..., drop = FALSE) {
     y <- as.data.frame(x)[i, j, drop = drop]
     if (identical(colnames(x), colnames(y))) {
-      Resamples(y, control = x@control, strata = x@strata)
+      Resample(y, control = x@control, case_comps = x@case_comps)
     } else y
   }
 )
@@ -110,7 +116,7 @@ setMethod("[", c(x = "Resamples", i = "ANY", j = "ANY", drop = "ANY"),
 
 #' @rdname extract-methods
 #'
-setMethod("[", c(x = "Resamples", i = "ANY", j = "missing", drop = "ANY"),
+setMethod("[", c(x = "Resample", i = "ANY", j = "missing", drop = "ANY"),
   function(x, i, j, ..., drop = FALSE) {
     ninds <- nargs() - 1 - !missing(drop)
     if (ninds > 1) x[i, TRUE, drop = drop] else x[, i, drop = FALSE]
@@ -120,7 +126,7 @@ setMethod("[", c(x = "Resamples", i = "ANY", j = "missing", drop = "ANY"),
 
 #' @rdname extract-methods
 #'
-setMethod("[", c(x = "Resamples", i = "missing", j = "missing", drop = "ANY"),
+setMethod("[", c(x = "Resample", i = "missing", j = "missing", drop = "ANY"),
   function(x, i, j, ..., drop = FALSE) {
     x[, TRUE, drop = drop]
   }
@@ -142,8 +148,8 @@ setMethod("[", c(x = "SurvMatrix", i = "ANY", j = "ANY", drop = "ANY"),
 
 #' @rdname extract-methods
 #'
-setMethod("[", c(x = "SurvMeans", i = "ANY", j = "missing", drop = "missing"),
+setMethod("[", c(x = "SurvTimes", i = "ANY", j = "missing", drop = "missing"),
   function(x, i) {
-    new("SurvMeans", asS3(x)[i], distr = x@distr)
+    new(class(x), asS3(x)[i], distr = x@distr)
   }
 )
