@@ -34,6 +34,27 @@ utils::globalVariables(c("x", "y"))
 }
 
 
+as_string <- function(x, ...) {
+  UseMethod("as_string")
+}
+
+
+as_string.default <- function(x, ...) {
+  x <- format(x, trim = TRUE)
+  as_string(structure(as.character(x), names = names(x)), ...)
+}
+
+
+as_string.character <- function(x, sep = ", ", conj = character()) {
+  if (length(conj)) {
+    n <- length(x)
+    if (n > 1) x[n] <- paste(conj, x[n])
+    if (n == 2) x <- paste(x[1], x[2])
+  }
+  if (length(sep)) paste(x, collapse = sep) else x
+}
+
+
 attach_objects <- function(
   what, pos = 2L, name = deparse1(substitute(what), backtick = FALSE)
 ) {
@@ -52,7 +73,7 @@ combine_data_frames <- function(x, y = NULL) {
   if (is.null(y)) return(x)
   common_cols <- intersect(names(x), names(y))
   if (!identical(x[common_cols], y[common_cols])) {
-    throw(Error("common columns in data frames differ"))
+    throw(Error("Common columns in data frames differ."))
   }
   diff_cols <- setdiff(names(y), common_cols)
   x[diff_cols] <- y[diff_cols]
@@ -62,7 +83,7 @@ combine_data_frames <- function(x, y = NULL) {
 
 combine_model_slots <- function(models, types) {
   init <- data.frame(type = types, weights = FALSE)
-  any_ordered <- any(map_logi(function(model) {
+  any_ordered <- any(map("logi", function(model) {
     "ordered" %in% model@response_types
   }, models))
   info_list <- map(function(model) {
@@ -106,9 +127,9 @@ fget <- function(x) {
   f <- get0(x, mode = "function")
   if (is.null(f)) {
     msg <- if (is.character(x)) {
-      paste0("function '", x, "' not found")
+      paste0("Function '", x, "' not found.")
     } else {
-      "invalid function"
+      "Invalid function."
     }
     throw(Error(msg))
   }
@@ -133,40 +154,16 @@ get0 <- function(x, mode = "any") {
 }
 
 
-get_MLObject <- function(x, class = c("MLControl", "MLMetric", "MLModel")) {
-  class <- match.arg(class)
-  x <- get0(x)
-  if (is.function(x) && class %in% c("MLControl", "MLModel")) x <- x()
-  if (!is(x, class)) throw(TypeError(x, class, "'x'"))
-  x
-}
-
-
-get_MLControl <- function(x) {
-  get_MLObject(x, class = "MLControl")
-}
-
-
-get_MLMetric <- function(x) {
-  get_MLObject(x, class = "MLMetric")
-}
-
-
-get_MLModel <- function(x) {
-  get_MLObject(x, class = "MLModel")
-}
-
-
 get_perf_metrics <- function(x, y) {
   generic_name <- "performance"
   classes <- substring(methods(generic_name), nchar(generic_name) + 2)
   class <- match_class(x, classes)
   method <- fget(paste0(generic_name, ".", class))
   metrics <- c(eval(formals(method)$metrics))
-  is_defined <- map_logi(function(metric) {
+  is_defined <- map("logi", function(metric) {
     types <- metricinfo(metric)[[1]]$response_types
-    any(map_logi(is, list(x), types$observed) &
-          map_logi(is, list(y), types$predicted))
+    any(map("logi", is, list(x), types$observed) &
+          map("logi", is, list(y), types$predicted))
   }, metrics)
   metrics[is_defined]
 }
@@ -185,7 +182,7 @@ has_varimp <- function(object) {
 identical_elements <- function(x, transform = identity, ...) {
   target <- transform(x[[1]])
   compare <- function(current) identical(transform(current), target, ...)
-  all(map_logi(compare, x[-1]))
+  all(map("logi", compare, x[-1]))
 }
 
 
@@ -194,13 +191,18 @@ is_counting <- function(x) {
 }
 
 
+is_empty <- function(x) {
+  length(x) == 0
+}
+
+
 is_one_element <- function(x, class = "ANY") {
   is.vector(x) && length(x) == 1 && is(x[[1]], class)
 }
 
 
 is_response <- function(y, types) {
-  map_logi(function(type) {
+  map("logi", function(type) {
     if (type == "binary") {
       is(y, "factor") && nlevels(y) == 2
     } else {
@@ -216,7 +218,12 @@ is_trained <- function(x, ...) {
 
 
 is_trained.MLModel <- function(x, ...) {
-  length(x@train_steps) > 0
+  length(x@steps) > 0
+}
+
+
+is_trained.ModelRecipe <- function(x, ...) {
+  recipes::fully_trained(x)
 }
 
 
@@ -225,89 +232,56 @@ is_trained.step <- function(x, ...) {
 }
 
 
-label_items <- function(label, x, n = Inf, add_names = FALSE) {
-  item_len <- length(x)
-  if (add_names && !is.null(names(x))) x <- paste(names(x), x, sep = " = ")
-  items <- if (n < item_len) paste(toString(head(x, n)), "...") else toString(x)
-  if (item_len != 1) label <- paste0(label, "s")
-  if (item_len) paste0(label, ": ", items) else label
+make_id <- function(n = 8) {
+  paste(sample(c(letters, 0:9), n, replace = TRUE), collapse = "")
 }
 
 
-list_to_function <- function(x, type) {
-  err_msg <- paste0("'", deparse1(substitute(x)), "' must be a function, ",
-                      "function name, or vector of these")
-  if (is(x, "MLMetric")) x <- list(x)
-  if (is(x, "vector")) {
-    x <- as.list(x)
-    x_names <- character()
-    for (i in seq_along(x)) {
-      if (is(x[[i]], "character")) {
-        x_name <- x[[i]]
-        x[[i]] <- fget(x_name)
-      } else if (is(x[[i]], "MLMetric")) {
-        x_name <- x[[i]]@name
-      } else if (is(x[[i]], "function")) {
-        x_name <- type
-      } else {
-        throw(Error(err_msg))
-      }
-      name <- names(x)[i]
-      x_names[i] <- if (is.null(name) || !nzchar(name)) x_name else name
-    }
-    names(x) <- make.unique(x_names)
-    function(...) unlist(map(function(fun) fun(...), x))
-  } else if (is(x, "function")) {
-    x
-  } else {
-    throw(Error(err_msg))
-  }
-}
-
-
-make_list_names <- function(x, prefix) {
+make_names_along <- function(x, default = "..", sep = ".") {
+  if (length(default) == 1) default <- rep(default, length = length(x))
   old_names <- names(x)
-  names(x) <- if (length(x)) {
-    if (length(x) > 1) paste0(prefix, ".", seq_along(x)) else prefix
-  }
+  names(x) <- default
   if (!is.null(old_names)) {
-    keep <- nzchar(old_names)
+    keep <- nzchar(old_names) & !is.na(old_names)
     names(x)[keep] <- old_names[keep]
   }
-  names(x)
+  make_unique(names(x), sep = sep)
 }
 
 
-map <- function(FUN, ...) {
-  all_args <- all(lengths(list(...)))
-  if (all_args) mapply(FUN = FUN, ..., SIMPLIFY = FALSE) else list()
+make_names_len <- function(n, prefix) {
+  paste0(rep(prefix, n), seq_len(n))
 }
 
 
-map_chr <- function(FUN, ...) {
-  res <- map_simplify(FUN, ...)
-  storage.mode(res) <- "character"
+make_unique <- function(names, sep = ".") {
+  sort_order <- order(names)
+  counts <- table(names)
+  unames <- map(function(count, name) {
+    paste0(name, if (count > 1) paste0(sep, seq_len(count)))
+  }, counts, names(counts))
+  names[sort_order] <- unlist(unames)
+  names
+}
+
+
+map <- function(.object, ...) {
+  UseMethod("map")
+}
+
+
+map.character <- function(.object, .fun, ...) {
+  type <- match.arg(.object, c("character", "complex", "double", "integer",
+                               "list", "logical", "numeric", "raw"))
+  res <- simplify(map(.fun, ...))
+  storage.mode(res) <- type
   res
 }
 
 
-map_logi <- function(FUN, ...) {
-  res <- map_simplify(FUN, ...)
-  storage.mode(res) <- "logical"
-  res
-}
-
-
-map_num <- function(FUN, ...) {
-  res <- map_simplify(FUN, ...)
-  storage.mode(res) <- "numeric"
-  res
-}
-
-
-map_simplify <- function(FUN, ...) {
-  res <- map(FUN, ...)
-  if (length(res)) simplify2array(res, higher = TRUE) else res
+map.function <- function(.object, ...) {
+  nonempty <- all(lengths(list(...)))
+  if (nonempty) mapply(FUN = .object, ..., SIMPLIFY = FALSE) else list()
 }
 
 
@@ -324,10 +298,11 @@ match_class <- function(object, choices) {
 match_indices <- function(indices, choices) {
   lookup <- structure(seq_along(choices), names = choices)
   indices <- na.omit(names(lookup)[lookup[indices]])
-  if (length(indices) == 0) {
+  if (is_empty(indices)) {
     indices <- names(lookup)[1]
-    throw(LocalWarning("specified indices not found; using ", indices,
-                       " instead"))
+    throw(LocalWarning(
+      "Specified indices not found; using ", indices, " instead."
+    ))
   }
   indices
 }
@@ -344,27 +319,28 @@ missing_names <- function(x, data) {
 
 
 new_params <- function(envir, ...) {
-  args <- as.list(envir)
-  is_missing <- map_logi(function(x) is.symbol(x) && !nzchar(x), args)
-  if (any(is_missing)) {
-    missing <- names(args)[is_missing]
-    throw(Error(label_items("missing values for required argument", missing)))
+  args <- c(as.list(envir), ...)
+  missing <- map("logi", function(x) is.symbol(x) && !nzchar(x), args)
+  if (any(missing)) {
+    throw(Error(note_items(
+      "Missing values for required argument{?s}: ", names(args)[missing], "."
+    )))
   }
-  c(args[!map_logi(is.null, args)], list(...))
+  args[lengths(args) > 0]
 }
 
 
 new_progress_bar <- function(total, input = NULL, model = NULL, index = 0) {
   if (getDoParName() == "doSEQ") index <- as.numeric(index)
-  width <- max(10, round(0.25 * getOption("width")))
+  width <- max(round(0.25 * console_width()), 10)
   if (!is.null(input)) input <- substr(class1(input), 1, width)
   if (!is.null(model)) {
-    model <- substr(get_MLModel(model)@name, 1, width)
+    model <- substr(as.MLModel(model)@name, 1, width)
   }
   format <- paste(input, "|", model)
   if (index > 0) format <- paste0(index, ": ", format)
   if (getDoParName() %in% c("doSEQ", "doSNOW")) {
-    format <- paste(format, "[:bar] :percent | :elapsed")
+    format <- paste(format, "[:bar] :percent | :eta")
   }
   pb <- progress_bar$new(
     format = format,
@@ -380,8 +356,8 @@ new_progress_bar <- function(total, input = NULL, model = NULL, index = 0) {
 }
 
 
-new_progress_index <- function(names, max) {
-  structure(0, names = names, max = max, class = c("progress_index", "numeric"))
+new_progress_index <- function(name, max) {
+  structure(0, names = name, max = max, class = c("progress_index", "numeric"))
 }
 
 
@@ -392,7 +368,7 @@ ndim <- function(x) {
 
 nvars <- function(x, model) {
   stopifnot(is(x, "ModelFrame"))
-  model <- get_MLModel(model)
+  model <- as.MLModel(model)
   res <- switch(model@predictor_encoding,
     "model.frame" = {
       x_terms <- attributes(terms(x))
@@ -404,20 +380,42 @@ nvars <- function(x, model) {
 }
 
 
+note_items <- function(
+  begin, values, end = character(), add_names = FALSE, sep = ", ",
+  conj = character()
+) {
+  if (add_names && length(names(values))) {
+    values <- paste(names(values), values, sep = " = ")
+  }
+  qty <- "{qty(length(values))}"
+  pluralize(paste0(begin, as_string(values, sep = sep, conj = conj), end, qty))
+}
+
+
+permute_int <- function(n, size = n) {
+  inds <- sample.int(n, size)
+  half_size <- size / 2
+  inds1 <- head(inds, half_size)
+  inds2 <- tail(inds, -half_size)
+  res <- data.frame(i = c(inds1, inds2), j = c(inds2, inds1))
+  res[order(res$i), ]
+}
+
+
 push <- function(x, object, ...) {
   UseMethod("push")
 }
 
 
-push.TrainStep <- function(x, object, ...) {
+push.TrainingStep <- function(x, object, ...) {
   stopifnot(is(object, "MLModelFit"))
   mlmodel <- if (isS4(object)) object@mlmodel else object$mlmodel
-  train_steps <- ListOf(c(x, mlmodel@train_steps))
-  names(train_steps) <- paste0("TrainStep", seq_along(train_steps))
+  steps <- ListOf(c(x, mlmodel@steps))
+  names(steps) <- make_names_len(length(steps), class(x))
   if (isS4(object)) {
-    object@mlmodel@train_steps <- train_steps
+    object@mlmodel@steps <- steps
   } else {
-    object$mlmodel@train_steps <- train_steps
+    object$mlmodel@steps <- steps
   }
   object
 }
@@ -428,59 +426,16 @@ rand_int <- function(n = 1) {
 }
 
 
-require_namespaces <- function(packages) {
-  paren_pos <- regexpr("\\(([^)]*)\\)", packages)
-  paren_len <- attr(paren_pos, "match.length")
-
-  end_pos <- ifelse(paren_pos > 0, paren_pos - 1, nchar(packages))
-  package_names <- trimws(substr(packages, 1, end_pos))
-
-  package_errors <- function(x, msg, fix) {
-    if (any(x)) {
-      items <- packages[x]
-      item_names <- package_names[x]
-      throw(LocalError("Call ", label_items(msg, items), ".\n",
-                       "To address this issue, try running ", fix, "(",
-                       deparse1(item_names), ")."))
-    }
-  }
-
-  installed <- map_logi(requireNamespace, package_names, quietly = TRUE)
-  package_errors(!installed, "requires prior installation of package",
-                 "install.packages")
-
-  end_pos <- paren_pos + paren_len - 2
-  compat_versions <- strsplit(substr(packages, paren_pos + 1, end_pos), " ")
-
-  compatible <- map_logi(function(package_name, compat_version) {
-    if (length(compat_version) == 2) {
-      version <- packageVersion(package_name)
-      eval(call(compat_version[1], version, compat_version[2]))
-    } else TRUE
-  }, package_names, compat_versions)
-  package_errors(!compatible, "requires updated package version",
-                 "update.packages")
-
-  invisible(installed & compatible)
-}
-
-
-sample_params <- function(x, size = NULL, replace = FALSE) {
+sample_params <- function(x, size = integer(), replace = FALSE) {
   stopifnot(is.list(x))
 
   n <- length(x)
   if (n == 0) return(tibble())
 
-  var_names <- paste0("Var", seq_along(x))
-  x_names <- names(x)
-  if (!is.null(x_names)) {
-    is_nzchar <- nzchar(x_names)
-    var_names[is_nzchar] <- x_names[is_nzchar]
-  }
-  names(x) <- var_names
+  names(x) <- make_names_along(x, make_names_len(length(x), "Var"))
 
   max_size <- prod(lengths(x))
-  if (is.null(size)) size <- max_size
+  if (is_empty(size)) size <- max_size
   if (!replace) size <- min(size, max_size)
 
   grid <- as_tibble(matrix(nrow = 0, ncol = n, dimnames = list(NULL, names(x))))
@@ -495,8 +450,8 @@ sample_params <- function(x, size = NULL, replace = FALSE) {
   grid <- head(grid, size)
   sortable_types <- c("character", "complex", "Date", "factor", "logical",
                       "numeric")
-  is_sortable <- map_logi(function(column) {
-    any(map_logi(is, list(column), sortable_types))
+  is_sortable <- map("logi", function(column) {
+    any(map("logi", is, list(column), sortable_types))
   }, grid)
   if (any(is_sortable)) {
     sort_order <- do.call(order, rev(grid[is_sortable]))
@@ -575,7 +530,7 @@ set_model_names <- function(x) {
       levels(x[[i]][[name]])
     }
   }
-  level_names <- level_names %>% unlist %>% make.unique %>% relist(level_names)
+  level_names <- level_names %>% unlist %>% make_unique %>% relist(level_names)
 
   for (i in seq_along(x)) levels(x[[i]][[name]]) <- level_names[[i]]
 
@@ -583,10 +538,15 @@ set_model_names <- function(x) {
 }
 
 
-size <- function(x, dim = NULL) {
+simplify <- function(x) {
+  if (length(x)) simplify2array(x, higher = TRUE) else x
+}
+
+
+size <- function(x, dim = integer()) {
   res <- dim(x)
   if (is.null(res)) res <- length(x)
-  if (is.null(dim)) res else res[dim]
+  if (length(dim)) res[dim] else res
 }
 
 
@@ -598,6 +558,15 @@ stepAIC_args <- function(formula, direction, scope) {
 }
 
 
+subset_selected <- function(object, slot_name, id = character()) {
+  if (length(id)) {
+    keep <- map("char", slot, slot(object, slot_name), "id") %in% id
+    slot(object, slot_name) <- slot(object, slot_name)[keep]
+  }
+  object
+}
+
+
 subset_names <- function(x, select = NULL) {
   indices <- seq_along(x)
   names(indices) <- x
@@ -607,7 +576,7 @@ subset_names <- function(x, select = NULL) {
   } else if (is.numeric(select)) {
     x <- x[select]
   } else if (!is.null(select)) {
-    throw(Warning("invalid 'select' value of class ", class1(select)))
+    throw(Warning("Invalid 'select' value of class ", class1(select), "."))
   }
   x
 }
@@ -619,16 +588,6 @@ switch_class <- function(EXPR, ...) {
 }
 
 
-toString.character <- function(x, conjunction = NULL, ...) {
-  if (!is.null(conjunction)) {
-    n <- length(x)
-    if (n > 1) x[n] <- paste(conjunction, x[n])
-    if (n == 2) x <- paste(x[1], x[2])
-  }
-  NextMethod()
-}
-
-
 unnest <- function(data) {
   stopifnot(is(data, "data.frame"))
   df <- data.frame(row.names = seq_len(nrow(data)))
@@ -642,3 +601,35 @@ unnest <- function(data) {
   }
   df
 }
+
+
+vector_to_function <- function(x, type) {
+  err_msg <- paste0("Value of '", deparse1(substitute(x)),
+                    "' must be a function, function name, or vector of these.")
+  if (is(x, "MLMetric")) x <- list(x)
+  if (is(x, "vector")) {
+    x <- as.list(x)
+    types <- make_names_len(length(x), type)
+    x_names <- character()
+    for (i in seq_along(x)) {
+      if (is(x[[i]], "character")) {
+        x_name <- x[[i]]
+        x[[i]] <- fget(x_name)
+      } else if (is(x[[i]], "MLMetric")) {
+        x_name <- x[[i]]@name
+      } else if (is(x[[i]], "function")) {
+        x_name <- types[i]
+      } else {
+        throw(Error(err_msg))
+      }
+      name <- names(x)[i]
+      x_names[i] <- if (is.null(name) || !nzchar(name)) x_name else name
+    }
+    names(x) <- make_unique(x_names)
+    function(...) unlist(map(function(fun) fun(...), x))
+  } else if (is(x, "function")) {
+    x
+  } else {
+    throw(Error(err_msg))
+  }
+}
