@@ -1,35 +1,33 @@
-VarImp <- function(object, ...) {
-  UseMethod("VarImp")
+VariableImportance <- function(object, ...) {
+  UseMethod("VariableImportance")
 }
 
 
-VarImp.default <- function(object, scale = TRUE, ...) {
+VariableImportance.default <- function(object, scale = TRUE, ...) {
   stopifnot(nrow(object) == 0 || is.character(rownames(object)))
 
   object <- object[rownames(object) != "(Intercept)", , drop = FALSE]
-  if (scale) {
-    object_shift <- min(object)
-    object_scale <- diff(range(object)) / 100
-    object <- (object - object_shift) / object_scale
+  if (scale) scale <- max(object, 0) / 100
+  if (scale > 0) {
+    object <- object / scale
     sort_vals <- rowSums(object)
   } else {
-    object_shift = 0
-    object_scale = 1
+    scale <- 1
     sort_vals <- object[, 1]
   }
   object <- object[order(sort_vals, decreasing = TRUE), , drop = FALSE]
 
-  new("VarImp", object, shift = object_shift, scale = object_scale)
+  new("VariableImportance", object, scale = scale)
 }
 
 
-VarImp.matrix <- function(object, ...) {
-  VarImp(as.data.frame(object), ...)
+VariableImportance.matrix <- function(object, ...) {
+  VariableImportance(as.data.frame(object), ...)
 }
 
 
-VarImp.numeric <- function(object, ...) {
-  VarImp(cbind(Overall = object), ...)
+VariableImportance.numeric <- function(object, ...) {
+  VariableImportance(cbind(Overall = object), ...)
 }
 
 
@@ -39,16 +37,14 @@ VarImp.numeric <- function(object, ...) {
 #'
 #' @param object model \link{fit} result.
 #' @param method character string specifying the calculation of variable
-#'   importance as model-specific (\code{"model"}) or permutation-base
-#'   (\code{"permute"}).  If model-specific importance is specified but not
+#'   importance as permutation-base (\code{"permute"}) or model-specific
+#'   (\code{"model"}).  If model-specific importance is specified but not
 #'   defined, the permutation-based method will be used instead with its default
-#'   values (below).  To change the default permutation values, set
-#'   \code{method = "permute"}.  Permutation-based variable importance is
-#'   defined as the relative change in model predictive performances between
-#'   datasets with and without permuted values for the associated variable
-#'   (Fisher et al. 2019).
-#' @param scale logical indicating whether importance measures should be scaled
-#'   to range from 0 to 100.
+#'   values (below).  Permutation-based variable importance is defined as the
+#'   relative change in model predictive performances between datasets with and
+#'   without permuted values for the associated variable (Fisher et al. 2019).
+#' @param scale logical indicating whether importance values should be scaled to
+#'   a maximum of 100.
 #' @param ... arguments passed to model-specific or permutation-based variable
 #'   importance functions.  These include the following arguments and default
 #'   values for \code{method = "permute"}.
@@ -59,11 +55,14 @@ VarImp.numeric <- function(object, ...) {
 #'     \item{\code{samples = 1}}{number of times to permute the values of each
 #'       variable.  Larger numbers of samples decrease variability in the
 #'       estimates at the expense of increased computation time.}
-#'     \item{\code{size = NULL}}{number of observations to sample without
-#'       replacement at each round of variable permutations [default: all].
-#'       Subsampling of observations will decrease computation time.}
-#'     \item{\code{prop = NULL}}{proportion of observations to sample at each
+#'     \item{\code{prop = numeric()}}{proportion of observations to sample
+#'       without replacement at each round of variable permutations [default:
+#'       all].  Subsampling of observations can decrease computation time.}
+#'     \item{\code{size = integer()}}{number of observations to sample at each
 #'       round of permutations [default: all].}
+#'     \item{\code{times = numeric()}}{numeric vector of follow-up times at
+#'       which to predict survival probabilities or \code{NULL} for predicted
+#'       survival means.}
 #'     \item{\code{metric = NULL}}{\link[=metrics]{metric} function or function
 #'       name with which to calculate performance.  If not specified, the first
 #'       applicable default metric from the \link{performance} functions is
@@ -72,15 +71,14 @@ VarImp.numeric <- function(object, ...) {
 #'       change to compute in comparing model predictive performances between
 #'       datasets with and without permuted values.  The choices are difference
 #'       (\code{"-"}) and ratio (\code{"/"}).}
-#'     \item{\code{stats = MachineShop::settings("stats.VarImp")}}{function,
-#'       function name, or vector of these with which to compute summary
-#'       statistics on the set of variable importance values from the permuted
-#'       datasets.}
+#'     \item{\code{stats = c(mean = "base::mean")}}{function, function name, or
+#'       vector of these with which to compute summary statistics on the set of
+#'       variable importance values from the permuted datasets.}
 #'     \item{\code{na.rm = TRUE}}{logical indicating whether to exclude missing
 #'       variable importance values from the calculation of summary statistics.}
 #'   }
 #'
-#' @return \code{VarImp} class object.
+#' @return \code{VariableImportance} class object.
 #'
 #' @references
 #' Fisher, A., Rudin, C., & Dominici, F. (2019). All models are wrong, but many
@@ -102,10 +100,18 @@ VarImp.numeric <- function(object, ...) {
 #' plot(vi)
 #' }
 #'
-varimp <- function(object, method = c("model", "permute"), scale = TRUE, ...) {
+varimp <- function(object, method = c("permute", "model"), scale = TRUE, ...) {
   stopifnot(is(object, "MLModelFit"))
   model <- as.MLModel(object)
-  require_namespaces(model@packages)
+  throw(check_packages(model@packages))
+
+  if (missing(method)) {
+    throw(Warning(
+      "The default method has changed from \"model\" to \"permute\"; ",
+      "set 'method = \"model\"' to revert to the previous behavior."
+    ), times = 3)
+  }
+
   switch(match.arg(method),
     "model" = {
       args <- dep_varimpargs(...)
@@ -117,31 +123,18 @@ varimp <- function(object, method = c("model", "permute"), scale = TRUE, ...) {
       vi <- do.call(varimp_permute, args, envir = parent.frame())
     }
   )
-  VarImp(vi, scale = scale)
-}
-
-
-dep_varimpargs <- function(metric, ...) {
-  args <- list(...)
-  if (!missing(metric)) {
-    throw(DeprecatedCondition(
-      "Argument 'metric' to varimp()", "'type'",
-      expired = Sys.Date() >= "2021-12-01"
-    ), call = FALSE)
-    args$type <- metric
-  }
-  args
+  VariableImportance(vi, scale = scale)
 }
 
 
 varimp_permute <- function(
-  object, select = NULL, samples = 1, size = NULL, prop = NULL, metric = NULL,
-  compare = c("-", "/"), stats = MachineShop::settings("stats.VarImp"),
-  na.rm = TRUE
+  object, select = NULL, samples = 1, prop = numeric(), size = integer(),
+  times = numeric(), metric = NULL, compare = c("-", "/"),
+  stats = c(mean = "base::mean"), na.rm = TRUE
 ) {
-  x <- as.MLModel(object)@x
-  data <- if (is.data.frame(x)) x else as.data.frame(x)
-  pred_names <- all.vars(predictors(terms(x, original = TRUE)))
+  input <- as.MLModel(object)@input
+  data <- if (is.data.frame(input)) input else as.data.frame(input)
+  pred_names <- all.vars(predictors(terms(input, original = TRUE)))
   pred_names <- do.call(subset_names, list(pred_names, substitute(select)),
                         envir = parent.frame())
 
@@ -149,23 +142,33 @@ varimp_permute <- function(
   throw(check_assignment(samples))
 
   n <- nrow(data)
-  size <- if (is.null(c(size, prop))) {
+  size <- if (is_empty(c(prop, size))) {
     n
-  } else if (is.null(prop)) {
+  } else if (is_empty(size)) {
+    prop <- check_numeric(prop, bounds = c(0, 1), include = 0:1, size = 1)
+    throw(check_assignment(prop))
+    min(max(prop * n, 2), n)
+  } else if (is_empty(prop)) {
     size <- check_numeric(size, bounds = c(2, Inf), size = 1)
     throw(check_assignment(size))
     min(size, n)
-  } else if (is.null(size)) {
-    prop <- check_numeric(prop, bounds = c(0, 1), include = 0:1, size = 1)
-    throw(check_assignment(prop))
-    max(min(2, n), n * prop)
   } else {
-    throw(Error("Arguments 'size' and 'prop' cannot be specified together."))
+    throw(Error("Arguments 'prop' and 'size' cannot be specified together."))
   }
 
+  if (!is.null(metric)) {
+    metric <- check_metric(metric, convert = TRUE)
+    throw(check_assignment(metric))
+  }
   compare <- match.arg(compare)
-  varimp <- function(x, y) do.call(compare, list(x, y))
-  stats <- list_to_function(stats, "stat")
+  varimp <- function(x, baseline, maximize = FALSE) {
+    do.call(compare, if (maximize) list(baseline, x) else list(x, baseline))
+  }
+  stats <- check_stats(stats, convert = TRUE)
+  throw(check_assignment(stats))
+  map_stats <- function(x) {
+    map(function(x) stats(if (na.rm) na.omit(x) else x), as.data.frame(x))
+  }
 
   num_workers <- getDoParWorkers()
   work <- pred_names
@@ -173,26 +176,17 @@ varimp_permute <- function(
   work_pred_names <- map(na.omit, split(work, seq_len(num_workers)))
   seeds <- rand_int(samples)
 
-  permute_int <- function(n, size = n) {
-    inds <- sample.int(n, size)
-    half_size <- size / 2
-    inds1 <- head(inds, half_size)
-    inds2 <- tail(inds, -half_size)
-    res <- data.frame(i = c(inds1, inds2), j = c(inds2, inds1))
-    res[order(res$i), ]
-  }
-
   pb <- progress_bar$new(
-    format = "varimp permute [:bar] :percent | :elapsed",
+    format = "varimp permute [:bar] :percent | :eta",
     total = samples * length(pred_names),
     show_after = 1
   )
   on.exit(pb$terminate())
 
-  sims <- foreach(
+  foreach(
     pred_names = work_pred_names[lengths(work_pred_names) > 0],
-    .combine = cbind,
-    .export = c("get_MLMetric", "get_perf_metrics"),
+    .combine = rbind,
+    .export = c("as.MLMetric", "get_perf_metrics", "map", "permute_int"),
     .packages = "MachineShop"
   ) %dopar% {
     subset <- size < n
@@ -205,29 +199,28 @@ varimp_permute <- function(
       base_perf[s] <- if (s == 1 || subset) {
         newdata <- if (subset) data[inds$i, ] else data
         obs <- response(object, newdata)
-        pred <- predict(object, newdata, type = "prob")
-        if (is.null(metric)) metric <- get_perf_metrics(obs, pred)[[1]]
-        metric <- get_MLMetric(metric)
-        performance(obs, pred, metrics = metric)[1]
+        pred <- predict(object, newdata, times = times, type = "prob")
+        if (is.null(metric)) {
+          metric <- as.MLMetric(get_perf_metrics(obs, pred)[[1]])
+        }
+        metric(obs, pred)[1]
       } else {
         base_perf[1]
       }
       for (name in pred_names) {
         x <- newdata[[name]]
         newdata[[name]] <- data[[name]][inds$j]
-        pred <- predict(object, newdata, type = "prob")
-        perf[s, name] <- performance(obs, pred, metrics = metric)[1]
+        pred <- predict(object, newdata, times = times, type = "prob")
+        perf[s, name] <- metric(obs, pred)[1]
         newdata[[name]] <- x
         pb$tick()
       }
     }
-    if (metric@maximize) varimp(base_perf, perf) else varimp(perf, base_perf)
+    sims <- varimp(perf, base_perf, metric@maximize)
+    res <- do.call(rbind, map_stats(sims))
+    colnames(res) <- paste0("Permute.", colnames(res), ".", metric@name)
+    res
   }
-
-  f <- function(x) stats(if (na.rm) na.omit(x) else x)
-  res <- do.call(rbind, map(f, as.data.frame(sims)))
-  colnames(res) <- paste0("Permute.", colnames(res))
-  res
 }
 
 
@@ -256,8 +249,8 @@ varimp_pval.lm <- function(object, base = exp(1), ...) {
 varimp_pval.mlm <- function(object, ...) {
   check <- check_equal_weights(object$weights)
   if (is(check, "warning")) {
-    throw(LocalWarning("model-specific variable importance not defined for ",
-                       class1(object), " with case weights"))
+    throw(LocalWarning("Model-specific variable importance not defined for ",
+                       class1(object), " with case weights."))
     NULL
   } else {
     object$weights <- NULL
